class Monster extends Sprite {
  color fillColor;
  float radius;
  Timer reverseTimer;
  float reverseAfter;

  Monster(float initX, float initY) {
    fillColor = color(107, 142, 35); // olive drab
    radius = random(25, 75);

    x = initX;
    y = initY;

    dx = random(3.0, 7.0);
    dy = random(3.0, 7.0);

    if (random(1.0) < 0.5) {
      dx = -dx;
    }
    if (random(1.0) < 0.5) {
      dy = -dy;
    }

    reverseTimer = new Timer();
    reverseAfter = random(1000, 15000);
  }

  void render() {
    pushMatrix();
    fill(fillColor);
    noStroke();
    ellipse(x, y, 2 * radius, 2 * radius);
    popMatrix();
  }

  void update() {
    super.update();
  
    if (reverseTimer.elapsedMillis() > reverseAfter) {
      dx = -dx;
      dy = -dy;
      reverseTimer.reset();
    }
  
    //
    // bounce off edges
    //
    if (x < 0) { // left edge
      x = 0;
      dx = -dx;
    }

    if (x > width) {  // right edge
      x = width;
      dx = -dx;
    }

    if (y < 0) {  // top edge
      y = 0;
      dy = -dy;
    }

    if (y > height) {  // bottom edge
      y = height;
      dy = -dy;
    }
  }

  boolean overlaps(Player p) {
    if (dist(x, y, p.x, p.y) <= radius + p.radius) {
      return true;
    } else {
      return false;
    }
  }
} // class Monster

